@@ -528,18 +528,6 @@ class WordType(caching.base.CachingMixin,models.Model):
         nd,fwnd = self.getNDs(subset=subset,speaker=speaker,dialog=dialog)
         return fwnd
 
-    def IDF(self):
-        if self.Extra is None:
-            self.Extra = {}
-        if 'IDF' in self.Extra:
-            return self.Extra['IDF']
-        base = WordToken.objects.all().select_related('WordType','Category')
-        freq = float(base.filter(WordType=self).count())/float(base.filter(~Q(Category__CategoryType='Other'),~Q(Category__CategoryType='Pause'),~Q(Category__CategoryType='Disfluency')).count())
-        idf = -1*math.log(freq)
-        self.Extra['IDF'] = idf
-        self.save()
-        return idf
-
     def getPhonoProb(self,subset='all',speaker=None,dialog=None):
         if subset == 'all' and self.SPhonoProb is not None and self.BiPhonoProb is not None:
             return self.SPhonoProb,self.BiPhonoProb
@@ -661,7 +649,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 return '.'.join([str(self),cat,'1'])
             prev = self.getPreviousContext(window=10)
             foll = self.getFollowingContext(window=10)
-            context = [[str(x),x.WordType.IDF()] for x in prev] + [[str(x),x.WordType.IDF()] for x in foll]
+            context = [str(x) for x in prev] + [str(x) for x in foll]
             self.Output['Wordnet_sense'] = disambiguate_sense(str(self),cat,context,to_string=True)
             self.save()
         return self.Output['Wordnet_sense']
